// Theme switcher
const themeSelect = document.getElementById('theme');
const body = document.body;

// Load saved theme
const savedTheme = localStorage.getItem('theme') || 'light';
body.classList.toggle('dark-theme', savedTheme === 'dark');
themeSelect.value = savedTheme;

// Theme change handler
themeSelect.addEventListener('change', (e) => {
  const selectedTheme = e.target.value;
  body.classList.toggle('dark-theme', selectedTheme === 'dark');
  localStorage.setItem('theme', selectedTheme);
});

// Sample client data
const clients = [
  { id: 1, name: 'Acme Corp', email: 'contact@acme.com' },
  { id: 2, name: 'Globex Inc', email: 'info@globex.com' }
];

// Sample invoice data
const invoices = [
  { id: 101, client: 'Acme Corp', amount: 1500, status: 'Paid' },
  { id: 102, client: 'Globex Inc', amount: 2500, status: 'Pending' }
];

// Render clients
function renderClients() {
  const clientList = document.querySelector('.client-list');
  clientList.innerHTML = clients.map(client => `
    <div class="client-item">
      <h3>${client.name}</h3>
      <p>${client.email}</p>
    </div>
  `).join('');
}

// Render invoices
function renderInvoices() {
  const invoiceList = document.querySelector('.invoice-list');
  invoiceList.innerHTML = invoices.map(invoice => `
    <div class="invoice-item">
      <h3>Invoice #${invoice.id}</h3>
      <p>Client: ${invoice.client}</p>
      <p>Amount: $${invoice.amount}</p>
      <p>Status: ${invoice.status}</p>
    </div>
  `).join('');
}

// Initial render
renderClients();
renderInvoices();

// Add client button handler
document.querySelector('.add-client-btn').addEventListener('click', () => {
  alert('Add new client functionality coming soon!');
});

// Create invoice button handler
document.querySelector('.create-invoice-btn').addEventListener('click', () => {
  alert('Create new invoice functionality coming soon!');
});